@@ -2310,7 +2310,7 @@ display_page_inserted_cb (RBDisplayPageModel *model, RBDisplayPage *page, GtkTre
 
 			if (category_data->match_source (source)) {
 				char *dbus_path;
-				dbus_path = g_strdup_printf ("%s/%" G_GINTPTR_FORMAT,
+				dbus_path = g_strdup_printf ("%s/%" G_GINTPTR_MODIFIER "u",
 							     category_data->dbus_path,
 							     (gintptr) source);
 				rb_debug ("adding new source %s to category %s", dbus_path, category_data->name);
@@ -2492,6 +2492,11 @@ impl_deactivate	(PeasActivatable *bplugin)
 		plugin->name_own_id = 0;
 	}
 
+	if (plugin->node_info != NULL) {
+		g_dbus_node_info_unref (plugin->node_info);
+		plugin->node_info = NULL;
+	}
+
 	if (plugin->connection != NULL) {
 		g_object_unref (plugin->connection);
 		plugin->connection = NULL;
