@@ -69,49 +69,6 @@ rb_nokia770_source_init (RBNokia770Source *source)
 
 }
 
-RBSource *
-rb_nokia770_source_new (GObject *plugin, RBShell *shell, GMount *mount, MPIDDevice *device_info)
-{
-	RBNokia770Source *source;
-	RhythmDBEntryType *entry_type;
-	RhythmDB *db;
-	GVolume *volume;
-	char *name;
-	char *path;
-
-	g_assert (rb_nokia770_is_mount_player (mount, device_info));
-
-	volume = g_mount_get_volume (mount);
-
-	g_object_get (G_OBJECT (shell), "db", &db, NULL);
-	path = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
-	name = g_strdup_printf ("nokia770: %s", path);
-
-	entry_type = g_object_new (RHYTHMDB_TYPE_ENTRY_TYPE,
-				   "db", db,
-				   "name", name,
-				   "category", RHYTHMDB_ENTRY_NORMAL,
-				   "save-to-disk", FALSE,
-				   NULL);
-	rhythmdb_register_entry_type (db, entry_type);
-	g_object_unref (db);
-	g_free (name);
-	g_free (path);
-	g_object_unref (volume);
-
-	source = RB_NOKIA770_SOURCE (g_object_new (RB_TYPE_NOKIA770_SOURCE,
-						   "plugin", plugin,
-						   "entry-type", entry_type,
-						   "mount", mount,
-						   "shell", shell,
-						   "device-info", device_info,
-						   NULL));
-
-	rb_shell_register_entry_type_for_source (shell, RB_SOURCE (source), entry_type);
-
-	return RB_SOURCE (source);
-}
-
 static char *
 impl_uri_from_playlist_uri (RBGenericPlayerSource *source, const char *uri)
 {
