@@ -261,6 +261,13 @@ create_source_device_cb (RBRemovableMediaManager *rmm, GObject *device_obj, RBMt
 		return NULL;
 	}
 
+	/* check that it's not an android device */
+	if (rb_removable_media_manager_device_is_android (rmm, device_obj)) {
+		rb_debug ("device %s is android based, android plugin should handle it",
+			  g_udev_device_get_name (device));
+		return NULL;
+	}
+
 	/* get device info */
 	vendor = get_property_as_int (device, "ID_VENDOR_ID", 16);
 	model = get_property_as_int (device, "ID_MODEL_ID", 16);
