@@ -744,8 +744,6 @@ impl_constructed (GObject *object)
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "podcast-add-dialog"));
 	gtk_box_pack_start (GTK_BOX (dialog), widget, TRUE, TRUE, 0);
 
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (dialog->priv->feed_view), TRUE);
-
 	/* set up episode view */
 	g_object_get (dialog->priv->shell, "shell-player", &shell_player, NULL);
 	episodes = rb_entry_view_new (dialog->priv->db, G_OBJECT (shell_player), TRUE, FALSE);
@@ -903,7 +901,7 @@ rb_podcast_add_dialog_class_init (RBPodcastAddDialogClass *klass)
 				       G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 				       G_STRUCT_OFFSET (RBPodcastAddDialogClass, close),
 				       NULL, NULL,
-				       g_cclosure_marshal_VOID__VOID,
+				       NULL,
 				       G_TYPE_NONE,
 				       0);
 	signals[CLOSED] = g_signal_new ("closed",
@@ -911,7 +909,7 @@ rb_podcast_add_dialog_class_init (RBPodcastAddDialogClass *klass)
 					G_SIGNAL_RUN_LAST,
 					G_STRUCT_OFFSET (RBPodcastAddDialogClass, closed),
 					NULL, NULL,
-					g_cclosure_marshal_VOID__VOID,
+					NULL,
 					G_TYPE_NONE,
 					0);
 
