@@ -245,7 +245,7 @@ rhythmdb_property_model_class_init (RhythmDBPropertyModelClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RhythmDBPropertyModelClass, pre_row_deletion),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL,
 			      G_TYPE_NONE,
 			      0);
 
