@@ -88,6 +88,17 @@ enum {
 	PROP_SHELL
 };
 
+G_GNUC_NORETURN static gboolean
+show_version_cb (const gchar *option_name,
+		 const gchar *value,
+		 gpointer     data,
+		 GError     **error)
+{
+	g_print ("%s %s\n", PACKAGE, VERSION);
+
+	exit (0);
+}
+
 static void
 load_uri_action_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data)
 {
@@ -423,9 +434,8 @@ impl_local_command_line (GApplication *app, gchar ***args, int *exit_status)
 	if (rb->priv->no_registration) {
 		if (n_files > 0) {
 			g_warning ("Unable to open files on the commandline with --no-registration");
+			n_files = 0;
 		}
-		impl_startup (app);
-		return TRUE;
 	}
 
 	if (!g_application_register (app, NULL, &error)) {
@@ -626,6 +636,7 @@ rb_application_run (RBApplication *app, int argc, char **argv)
 		{ "disable-plugins",   0, 0, G_OPTION_ARG_NONE,		&app->priv->disable_plugins, N_("Disable loading of plugins"), NULL },
 		{ "rhythmdb-file",     0, 0, G_OPTION_ARG_STRING,       &app->priv->rhythmdb_file,   N_("Path for database file to use"), NULL },
 		{ "playlists-file",    0, 0, G_OPTION_ARG_STRING,       &app->priv->playlists_file,   N_("Path for playlists file to use"), NULL },
+		{ "version",           0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, show_version_cb, N_("Show the version of the program"), NULL },
 		{ NULL }
 	};
 
@@ -650,7 +661,12 @@ rb_application_run (RBApplication *app, int argc, char **argv)
 	else
 		rb_debug_init (debug);
 
-	g_object_set (app, "register-session", !app->priv->no_registration, NULL);
+	if (app->priv->no_registration) {
+		GApplicationFlags flags;
+		g_object_get (app, "flags", &flags, NULL);
+		flags |= G_APPLICATION_NON_UNIQUE;
+		g_object_set (app, "flags", flags, NULL);
+	}
 
 	return g_application_run (G_APPLICATION (app), nargc, nargv);
 }
@@ -855,6 +871,7 @@ set_accelerator (RBApplication *app, GMenuModel *model, int item, gboolean enabl
 	const char *key;
 	const char *accel = NULL;
 	const char *action = NULL;
+	char *detailed_action;
 
 	iter = g_menu_model_iterate_item_attributes (model, item);
 	while (g_menu_attribute_iter_get_next (iter, &key, &value)) {
@@ -870,10 +887,17 @@ set_accelerator (RBApplication *app, GMenuModel *model, int item, gboolean enabl
 	g_object_unref (iter);
 
 	if (accel && action) {
+		const char *accels[2] = {
+			NULL,
+			NULL
+		};
+
 		if (enable)
-			gtk_application_add_accelerator (GTK_APPLICATION (app), accel, action, target);
-		else
-			gtk_application_remove_accelerator (GTK_APPLICATION (app), action, target);
+			accels[0] = accel;
+
+		detailed_action = g_action_print_detailed_name (action, target);
+		gtk_application_set_accels_for_action (GTK_APPLICATION (app), detailed_action, accels);
+		g_free (detailed_action);
 	}
 
 	if (target)
