@@ -62,8 +62,7 @@ struct _RBStatusbarClass
 
 GType			rb_statusbar_get_type	(void);
 
-RBStatusbar *		rb_statusbar_new	(RhythmDB *db,
-						 RBTrackTransferQueue *transfer_queue);
+RBStatusbar *		rb_statusbar_new	(RhythmDB *db);
 
 void			rb_statusbar_set_page	(RBStatusbar *statusbar,
 						 RBDisplayPage *page);
