@@ -391,7 +391,7 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBEntryViewClass, entry_added),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOXED,
+			      NULL,
 			      G_TYPE_NONE,
 			      1,
 			      RHYTHMDB_TYPE_ENTRY);
@@ -408,7 +408,7 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBEntryViewClass, entry_deleted),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOXED,
+			      NULL,
 			      G_TYPE_NONE,
 			      1,
 			      RHYTHMDB_TYPE_ENTRY);
@@ -424,7 +424,7 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBEntryViewClass, entries_replaced),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL,
 			      G_TYPE_NONE,
 			      0);
 	/**
@@ -441,7 +441,7 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBEntryViewClass, entry_activated),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOXED,
+			      NULL,
 			      G_TYPE_NONE,
 			      1,
 			      RHYTHMDB_TYPE_ENTRY);
@@ -457,7 +457,7 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBEntryViewClass, selection_changed),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL,
 			      G_TYPE_NONE,
 			      0);
 	/**
@@ -478,7 +478,7 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBEntryViewClass, show_popup),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOOLEAN,
+			      NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -496,7 +496,7 @@ rb_entry_view_class_init (RBEntryViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBEntryViewClass, have_selection_changed),
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOOLEAN,
+			      NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -1825,7 +1825,6 @@ rb_entry_view_constructed (GObject *object)
 	g_object_ref (view->priv->selection);
 
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (view->priv->treeview), TRUE);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view->priv->treeview), TRUE);
 	gtk_tree_selection_set_mode (view->priv->selection, GTK_SELECTION_MULTIPLE);
 
 	if (view->priv->is_drag_source) {
@@ -1850,7 +1849,6 @@ rb_entry_view_constructed (GObject *object)
 		GtkTreeViewColumn *column;
 		GtkCellRenderer *renderer;
 		GtkWidget *image_widget;
-		gint width;
 
 		/* Playing icon column */
 		column = GTK_TREE_VIEW_COLUMN (gtk_tree_view_column_new ());
@@ -1872,8 +1870,6 @@ rb_entry_view_constructed (GObject *object)
 		gtk_widget_show_all (image_widget);
 
 		gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
-		gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, NULL);
-		gtk_tree_view_column_set_fixed_width (column, width + 5);
 		gtk_tree_view_append_column (GTK_TREE_VIEW (view->priv->treeview), column);
 		g_signal_connect_swapped (renderer,
 					  "pixbuf-clicked",
